@@ -6,7 +6,7 @@ import requests
 from coolname import generate_slug
 import json
 import os
-from time import sleep
+from time import sleep,time
 import jwt
 from prettytable import PrettyTable
 import requirements as reqMod
@@ -17,8 +17,8 @@ import termcolor
 import random
 import py_compile
 from pathlib import Path
-from clouderizer_beta.cldz_aws_lambda import lambda_deploy, lambda_delete, aws_region_set
-from clouderizer_beta.utils import check_aws_cli_exists, check_sam_cli_exists
+from clouderizer.cldz_aws_lambda import lambda_deploy, lambda_delete, aws_region_set,lambda_deploy_codebuild
+from clouderizer.utils import check_aws_cli_exists
 from yaml import load, dump
 # from clouderizer_beta.utils import prepend_line
 try:
@@ -27,14 +27,16 @@ except ImportError:
     from yaml import Loader, Dumper
 
 # BASE_URL="https://showcase.clouderizer.com"
-BASE_URL="https://betaconsole.clouderizer.com"
+BASE_URL="https://showcase.clouderizer.com"
 SYNC_URL="https://serverless.clouderizer.com/function/"
 
 upload_endpoint = BASE_URL + '/api/awsconfig/generatepresignedurl'
+get_user_bucket_endpoint = BASE_URL + '/api/awsconfig/getbucket'
 
 LOCAL_PATH=os.getenv("HOME") + "/.clouderizer/creds"
 LOCAL_DIR=os.getenv("HOME") + "/.clouderizer"
 DOCKERFILES_LOC = LOCAL_DIR+"/dockerfiles/"
+TEMPLATES_LOC = LOCAL_DIR+"/templates/"
 LAMBDA_FUNCTION_DIR = LOCAL_DIR+ "/lambda-dir/function/"
 
 Path(LOCAL_DIR).mkdir(parents=True, exist_ok=True)
@@ -56,6 +58,19 @@ for dockerfile in dockerfiles:
 		if resp.status_code==200:
 			open(DOCKERFILES_LOC+dockerfile,"w").write(resp.text)
 
+aws_templates = ['codebuild_buildspec.yaml','codebuild_cloudformation_template.yaml']
+for template in aws_templates:
+	if not os.path.exists(TEMPLATES_LOC):
+		Path(TEMPLATES_LOC).mkdir(parents=True,exist_ok=True)
+
+	if not os.path.exists(TEMPLATES_LOC+template):
+		resp=requests.post(BASE_URL+'/givemeawstemplatescli',json={
+			"name": template
+		},headers={"Content-Type":"application/json"})
+
+		if resp.status_code==200:
+			open(TEMPLATES_LOC+template,"w").write(resp.text)
+
 display_table = PrettyTable()
 display_table.field_names = ['Project Name','Created At', 'Status', 'Status Message']
 
@@ -380,6 +395,21 @@ def upload_to_showcase(file_name,file_loc,company,auth_token):
 			# },headers={"Content-Type":"application/json"})
 	return "Some error occurred while uploading... try again"
 
+def get_user_s3_bucket(company,auth_token):
+	resp=requests.post(get_user_bucket_endpoint,json={
+			"company": company
+	},headers={"Content-Type":"application/json","Authorization": "Bearer "+auth_token})
+
+	# print(resp.text)
+	resp=parse_json(resp.text)
+
+	if "success" in resp:
+		if resp["success"] == True:
+			return resp["bucket"]
+	print("Some error occurred while fetching s3 bucket")
+	exit(0)
+
+
 def update_serving_model(servingmodel,data,auth_token):
 	# print(servingmodel,data)
 	try:
@@ -815,6 +845,12 @@ def invoke_publishproject(servingprojectid, infra, auth_token, invokepublishproj
 	if publishproject.status_code==200:
 		return parse_json(publishproject.text)
 	else:
+		if publishproject.status_code==500:
+			text = parse_json(publishproject.text)
+			if "success" in text:
+				return text['message']
+			else:
+				return text
 		return "Could not publish project"
 
 def invoke_deployproject(servingprojectid, auth_token):
@@ -930,6 +966,8 @@ class Clouderizer(object):
 
 		payload['projects']=[]
 
+		payload['awsCodeBuildSetup']="false"
+
 		with open(LOCAL_PATH,'w') as f:
 			f.write(json.dumps(payload))
 
@@ -967,7 +1005,7 @@ class Clouderizer(object):
 
 		for project in published_serving_projects:
 			url="-"
-			if "Deployed successfully" in project['status_message']:
+			if "deployed successfully" in project['status_message']:
 				project['status_message']="Deployed successfully"
 				url = BASE_URL + "/api/async-function/"+project['name']+"/notebook"
 				
@@ -975,7 +1013,7 @@ class Clouderizer(object):
 				project['status_message']="Error occurred" 
 
 			if project['status'] == "":
-				project['status'] = "Deploying"
+				project['status'] = "Not Running"
 
 			if len(project['status'])>status_truncation:
 				project['status']=project['status'][:status_truncation]
@@ -1056,18 +1094,80 @@ class Clouderizer(object):
 			print("Project not found")
 			return
 
-		stopproject_url=BASE_URL+"/api/servingproject/stopproject"
-		stopproject=requests.post(stopproject_url,headers=headers,data={"projectId":serving_project[0]["id"]})
+		servingproject=serving_project[0]
 
-		if stopproject.status_code==200:
-			print("Project "+name+ " stopped successfully")
-			createEvent("stop",creds['cid'],creds['token'],serving_project[0]["id"],name)
+		servingmodelsurl=BASE_URL+'/api/servingmodel?where={"servingproject":"%s"}' % (servingproject["id"])
+		servingmodel=requests.get(servingmodelsurl,headers=headers)
+		
+		servingmodel=parse_json(servingmodel.text)
 
-		if stopproject.status_code==401:
-			print("Could not authenticate you, try cldz login")
-		return
+		if len(servingmodel)==0:
+			print("Some error occurred")
+			return
 
-	def start(self, name,infra="standard"):
+		servingmodel = servingmodel[0]
+
+		# print(servingmodel["lambda"],type(servingmodel["lambda"]))
+		if servingmodel["lambda"]=="true" or(type(servingmodel["lambda"])==bool and servingmodel["lambda"]):
+			lambda_delete(name,LOCAL_DIR)
+		else:
+			stopproject_url=BASE_URL+"/api/servingproject/stopproject"
+			stopproject=requests.post(stopproject_url,headers=headers,data={"projectId":serving_project[0]["id"]})
+
+			if stopproject.status_code==200:
+				print("Project "+name+ " stopped successfully")
+				createEvent("stop",creds['cid'],creds['token'],serving_project[0]["id"],name)
+
+			if stopproject.status_code==401:
+				print("Could not authenticate you, try cldz login")
+			return
+
+	def env(self,command,key=None,value=None):
+
+		if command not in ["add","update","delete","get"]:
+			print("Not supported "+ command)
+			print("Available commands: add, update, delete")
+			return
+
+		if command!="get" and not key:
+			print("cldz env add KEY=VALUE")
+			return
+
+		if command in ["add","update"] and not value:
+			print("cldz env add KEY=VALUE")
+			return
+
+		creds=self.loggedin()
+		auth_token= creds['token']
+
+		ep = "nbvariables"
+		if command == "get":
+			ep="getnbvariables"
+
+		result = requests.post(BASE_URL+'/api/customer/'+ep,json={
+			"customerId": creds['cid'],
+			"type": command,
+			"key": key,
+			"value": value
+		},headers={"Content-Type":"application/json","Authorization": "Bearer "+auth_token})
+
+		# print(result.text)
+		result=parse_json(result.text)
+		# print(result)
+		if "success" in result:
+			if command=="get":
+				if result["success"]:
+					for d in result["data"]:
+						print("{}={}".format(d["key"],d["value"]))
+				else:
+					print(result["msg"])
+			else:
+				print(result["msg"])
+		else:
+			print("Some error occurred")
+
+
+	def deploy(self, name,infra="standard",image="standard"):
 		global loadingDisplay
 		if not name:
 			print("Choose a specific project!")
@@ -1076,6 +1176,16 @@ class Clouderizer(object):
 		creds=self.loggedin()
 		headers = {"Authorization":"Bearer "+creds["token"]}
 
+		if infra not in SUPPORTED_INFRA_TYPES:
+			print("--infra is not an accepted value")
+			print("Available infra types : standard, highmemory, gpu")
+			return
+
+		if image not in SUPPORTED_IMAGE_TYPES:
+			print("--image is not an accepted value")
+			print("Available image types : standard, torch, tensorflow")
+			return
+
 		name=find_full_project_name(name)
 
 		servingprojectsurl=BASE_URL+'/api/servingproject?where={"name":"%s","company":"%s"}' % (name,creds['cid'])
@@ -1105,7 +1215,7 @@ class Clouderizer(object):
 				return
 		else:
 			print(publishproject)
-			createEvent("start failed",creds['cid'],creds['token'],servingproject[0]["id"],name)
+			createEvent("start failed",creds['cid'],creds['token'],serving_project[0]["id"],name)
 			return			
 		
 
@@ -1213,13 +1323,20 @@ class Clouderizer(object):
 			if status_message=="Error Occurred":
 				print("Log dump")
 				print(published_serving_project[0]["status_message"])
+
+			if "otherfilenames" in serving_model and len(serving_model['otherfilenames'])>0:
+				print("\n")
+				print("SUPPORT FILES : ")
+				print(*serving_model['otherfilenames'],sep=', ')
+
+
 			if "Deployed successfully"==status_message:
 				if project_type=="NOTEBOOK" or not project_type:
 					if "accessUrl" in serving_model:
 						url = serving_model['accessUrl']
 						print("\nNOTEBOOK URL : "+ url)
 						print("\nSAMPLE ASYNC CURL COMMAND : "+ 'curl -i -X POST '+url + ' -F "param1=x" -F "param2=y" -F "file1=@<filepath1>" -F "file2=@<filepath2>" -H "x-callback-url: https://<callback-url-here>"')
-						print("\nSAMPLE SYNC CURL COMMAND : "+ 'curl -i -X POST '+surl + ' -F "param1=x" -F "param2=y" -F "file1=@<filepath1>" -F "file2=@<filepath2>"')
+						print("\nSAMPLE CURL COMMAND : "+ 'curl -i -X POST '+url + ' -F "param1=x" -F "param2=y" -F "file1=@<filepath1>" -F "file2=@<filepath2>"')
 					else:
 						url=BASE_URL + "/api/async-function/"+published_serving_project[0]["name"]+"/notebook"
 						surl=SYNC_URL + published_serving_project[0]["name"]+"/notebook"
@@ -1299,7 +1416,7 @@ class Clouderizer(object):
 
 		print("You have been successfully logged out")
 
-	def update(self,name,model=None,notebook=None,requirements=None,preprocess=None,postprocess=None,predict=None,disable=None):
+	def update(self,name,model=None,notebook=None,requirements=None,preprocess=None,postprocess=None,predict=None,disable=None,schema=None):
 	# def update(self,name,*args):
 		creds=self.loggedin()
 		auth_token=creds['token']
@@ -1310,6 +1427,10 @@ class Clouderizer(object):
 
 		name=find_full_project_name(name)
 
+		inputAttrs=[{"inputList":[], "rawinputList":[]}] 
+		outputAttrs=[{"outputList": [],"finaloutput":[]}]
+		if schema:
+			inputAttrs, outputAttrs = parse_yaml(schema)
 		# if not model and not notebook:
 		# 	print("Currently only model and notebook updates are supported")
 		# 	return
@@ -1365,9 +1486,10 @@ class Clouderizer(object):
 			if notebook_path:
 				file_name=notebook_path.split("/")[-1]
 				s3Path=servingproject["company"]+"/"+servingproject["name"]+"/"+file_name
+				print("Preparing notebook for upload")
 				uploadmodel_resp=upload_to_showcase(s3Path,notebook_path,servingproject["company"],auth_token)
 				if uploadmodel_resp=="Success":
-					print("Updating model file")
+					print("Updating notebook")
 
 					if not servingmodel:
 						servingmodel = get_serving_model(servingproject["id"])
@@ -1385,6 +1507,7 @@ class Clouderizer(object):
 				print("Updating requirements file")
 				servingmodel["pipPackages"]=pipPackages
 
+			servingmodel["savedon"] int(time())
 			updated_model=requests.put(BASE_URL+"/api/servingmodel/"+servingmodel["id"],headers=headers,data=servingmodel)
 				# print(updated_model.text)
 			print("Model updated successfully!")
@@ -1423,6 +1546,7 @@ class Clouderizer(object):
 			if model_path:
 				file_name=model_path.split("/")[-1]
 				model_s3_path=servingproject["company"]+"/"+servingproject["name"]+"/"+file_name
+				print("Preparing model file for upload")
 				uploadmodel_resp=upload_to_showcase(model_s3_path,model_path,servingproject["company"],auth_token)
 				if not uploadmodel_resp=="Success":
 					print(uploadmodel_resp)
@@ -1447,8 +1571,8 @@ class Clouderizer(object):
 			postprocess_s3_path=None
 			if postprocess_path:
 				print("Updating postprocess code")
-				file_name=postprocess_path.split("/")[-1]
-				postprocess_s3_path=servingproject["company"]+"/"+servingproject["name"]+"/"+file_name
+				postprocess_file_name=postprocess_path.split("/")[-1]
+				postprocess_s3_path=servingproject["company"]+"/"+servingproject["name"]+"/"+postprocess_file_name
 				uploadmodel_resp=upload_to_showcase(postprocess_s3_path,postprocess_path,servingproject["company"],auth_token)
 				if not uploadmodel_resp=="Success":
 					print(uploadmodel_resp)
@@ -1457,8 +1581,8 @@ class Clouderizer(object):
 			predict_s3_path=None
 			if predict_path and "python" in subtype:
 				print("Updating predict code")
-				file_name=predict_path.split("/")[-1]
-				predict_s3_path=servingproject["company"]+"/"+servingproject["name"]+"/"+file_name
+				predict_file_name=predict_path.split("/")[-1]
+				predict_s3_path=servingproject["company"]+"/"+servingproject["name"]+"/"+predict_file_name
 				uploadmodel_resp=upload_to_showcase(predict_s3_path,predict_path,servingproject["company"],auth_token)
 				if not uploadmodel_resp=="Success":
 					print(uploadmodel_resp)
@@ -1484,9 +1608,11 @@ class Clouderizer(object):
 				servingmodel["postprocessEnabled"]="true"
 
 			if disable=="preprocess":
+				print("Disabling preprocess function")
 				servingmodel["preprocessEnabled"]="false"
 
 			if disable=="postprocess":
+				print("Disabling postprocess function")
 				servingmodel["postprocessEnabled"]="false"
 
 			if preprocess_path:
@@ -1503,11 +1629,165 @@ class Clouderizer(object):
 				print("Updating requirements file")
 				servingmodel["pipPackages"]=pipPackages
 
+			servingmodel["savedon"] = int(time())
 			updated_model=requests.put(BASE_URL+"/api/servingmodel/"+servingmodel["id"],headers=headers,data=servingmodel)
 				# print(updated_model.text)
 			print("Model updated successfully!")
 
-	def deploy(self,file_path=None,requirements=None,predict=None,preprocess=None,postprocess=None,model_type=None,notebook_type=None,infra="standard",image="standard",schema=None):
+	def create(self,project_name,file_path=None,model_type=None,notebook_type=None,requirements=None):
+
+		execution_type="notebook"
+		subtype="pythonscore"
+		requirements_path = requirements
+		name = project_name
+
+		creds=self.loggedin()
+		auth_token=creds['token']
+
+		inputAttrs=[{"inputList":[], "rawinputList":[]}] 
+		outputAttrs=[{"outputList": [],"finaloutput":[]}]
+
+		if model_type and notebook_type:
+			print("Parameters unclear, both notebook and model types selected")
+			return
+
+		if model_type:
+			if model_type in SUPPORTED_MODEL_EXECUTION_TYPES:
+				execution_type="model"
+				if model_type=="python":
+					subtype="pythonscore"
+				else:
+					subtype=model_type
+			else:
+				print("Specified model type is not currently supported "+model_type)
+				print("Supported model types:")
+				for supported_model_type in SUPPORTED_MODEL_EXECUTION_TYPES:
+					print(supported_model_type)
+				return
+
+		if notebook_type:
+			if notebook_type in SUPPORTED_NOTEBOOK_EXECUTION_TYPES:
+				if notebook_type=="python":
+					subtype="pythonscore"
+				else:
+					subtype=notebook_type
+			else:
+				print("Specified notebook type is not currently supported")
+				for supported_notebook_type in SUPPORTED_NOTEBOOK_EXECUTION_TYPES:
+					print(supported_notebook_type)
+				return
+
+		if not file_path:
+			self.help()
+			return
+
+		pipPackages=None
+		if execution_type=="notebook":
+			notebook_path=file_path
+
+			checkPathExists(notebook_path)
+			# if not os.path.exists(notebook_path):
+			# 	print("Notebook path does not exist "+ notebook_path)
+			# 	return
+
+			if not notebook_path.endswith(".ipynb"):
+				print("File path does not point to a jupyter notebook" + notebook_path)
+				return
+
+			checkPathExists(requirements_path)
+			# if (requirements_path!=None and not os.path.exists(requirements_path)):
+			# 	print("Notebook path does not exist "+ requirements_path)
+			# 	return
+			
+			if requirements_path!=None:
+				pipPackages=parse_requirements(requirements_path)
+			else:
+				pipPackages=get_from_pipreqsnb(notebook_path)
+
+			print("TYPE : NOTEBOOK")
+			print("NOTEBOOK FILE PATH : " + notebook_path)
+			print("FETCHED PIP PACKAGES : ", pipPackages)		
+
+			print("Please check the above project attributes.")
+			display_timer("In case something looks wrong, press Ctrl + C and try again with correct values. Project creation will continue in ",10)	
+
+			servingproject=create_serving_project(notebook_path.split("/")[-1],creds['cid'],auth_token,projectName=name)
+			# print(type(servingproject))
+			if type(servingproject)==dict and "id" in servingproject:
+				update_local_project_list(servingproject["name"],"add")
+				# we will take filename from path
+				file_name=notebook_path.split("/")[-1]
+				s3Path=servingproject["company"]+"/"+servingproject["name"]+"/"+file_name
+				uploadmodel_resp=upload_to_showcase(s3Path,notebook_path,servingproject["company"],auth_token)
+				if uploadmodel_resp=="Success":
+					try:
+						servingmodel=create_serving_model(file_name,s3Path,servingproject,servingproject["id"],pipPackages,auth_token,"true","regular",subtype,"standard")
+					except Exception as e:
+						print(e)
+						print("Some exception occurred while preparing your notebook, please try again!")
+						return
+
+					if type(servingmodel)==dict and "id" in servingmodel:    
+						print("Project created!")
+
+					publishproject=invoke_publishproject(servingproject["id"],"standard",auth_token,False)
+					# if "success" in publishproject:
+					# 	print(publishproject)					
+
+		if execution_type=="model":
+			model_path=file_path
+
+			if not model_path:
+				print("Model not provided, exiting")
+				return
+
+			checkPathExists(model_path)
+			
+			if requirements_path!=None:
+				pipPackages=parse_requirements(requirements_path)
+
+			print("TYPE : MODEL")
+			print("MODEL PATH : " + model_path)
+			print("FETCHED PIP PACKAGES : ", pipPackages)
+
+			print("Please check the above project attributes.")
+			display_timer("In case something looks wrong, press Ctrl + C and try again with correct values. Deployment will continue in ",10)
+
+			servingproject=create_serving_project(model_path.split("/")[-1],creds['cid'],auth_token,inputAttrs=inputAttrs,outputAttrs=outputAttrs,projectName=name)
+			# print(type(servingproject))
+			if type(servingproject)==dict and "id" in servingproject:
+				update_local_project_list(servingproject["name"],"add")
+				# we will take filename from path
+				file_name=model_path.split("/")[-1]
+				s3Path=servingproject["company"]+"/"+servingproject["name"]+"/"+file_name
+				uploadmodel_resp=upload_to_showcase(s3Path,model_path,servingproject["company"],auth_token)
+
+				if uploadmodel_resp=="Success":					
+					try:
+						deployment_model_type="automl"
+						if subtype in ["python","onnx","pythonscore"]:
+							deployment_model_type="regular"
+						servingmodel=create_serving_model(file_name,s3Path,servingproject,servingproject["id"],pipPackages,auth_token,"false",deployment_model_type,subtype,"standard")
+					except Exception as e:
+						print(e)
+						print("Some exception occurred while preparing your model, please try again!")						
+						return
+
+					if type(servingmodel)==dict and "id" in servingmodel:    
+						# print("Project created!")
+						if subtype not in ["python","pythonscore","onnx"]:
+							print("Fetching I/O attributes from the project")
+							if not parser(model_path,servingproject,servingmodel["id"],subtype,auth_token):
+								print("Some error occurred while fetching attributes")
+								self.delete(servingproject["name"])
+								return
+
+					print("Project created!")
+
+					publishproject=invoke_publishproject(servingproject["id"],"standard",auth_token,False)
+					# print(publishproject)
+
+	def quickdeploy(self,file_path=None,requirements=None,predict=None,preprocess=None,postprocess=None,model_type=None,notebook_type=None,infra="standard",image="standard",schema=None):
 	# def deploy(self,first_path=None,second_path=None,third_path=None,model_type=None,notebook_type=None,enable_gpu=None):
 		global loadingDisplay
 		creds=self.loggedin()
@@ -1821,33 +2101,121 @@ class Clouderizer(object):
 			else:
 				print(servingproject)
 
-	# def dlambda(self,*args,**kwargs):
-	# 	lambda_commands = ['deploy','delete']
+	def addfiles(self, name, *args):
 
-	# 	if len(args)==0:
-	# 		print("No argument given")
-	# 		return
+		if not name or name=="":
+			print("Choose a specific project!")
+			return
 
-	# 	if args[0] not in lambda_commands:
-	# 		print("lambda command not supported, available commands : ",end = " ")
-	# 		for i in lambda_commands:
-	# 			print(i, end=" ")
-	# 		return
+		if len(args)==0:
+			print("no files given")
+			return
 
-	# 	if args[0]=="deploy":
-	# 		if len(args)==1:
-	# 			print("No file name given")
-	# 			return
+		creds=self.loggedin()		
+		auth_token=creds['token']
 
-	# 		file_path = args[1]
+		headers={"Content-Type":"application/json","Authorization": "Bearer "+auth_token}
 
-	# 		model_type=None
-	# 		if "m" in kwargs:
-	# 			model_type = kwargs["m"]
-	# 		if "model_type" in kwargs:
-	# 			model_type = kwargs["model_type"]
+		name=find_full_project_name(name)
 
-	# 		self.ldeploy(file_path,model_type)
+		print("Fetching project "+name)
+
+		servingprojectsurl=BASE_URL+'/api/servingproject?where={"name":"%s","company":"%s"}' % (name,creds['cid'])
+		serving_project=requests.get(servingprojectsurl,headers=headers)
+
+		serving_project = parse_json(serving_project.text)
+
+		if len(serving_project)==0 or type(serving_project)==str:
+			print("Project not found")
+			return
+
+		servingproject=serving_project[0]
+
+		servingmodelsurl=BASE_URL+'/api/servingmodel?where={"servingproject":"%s"}' % (servingproject["id"])
+		servingmodel=requests.get(servingmodelsurl,headers=headers)
+		
+		servingmodel=parse_json(servingmodel.text)
+
+		if len(servingmodel)==0:
+			print("Some error occurred")
+			return
+
+		servingmodel = servingmodel[0]
+
+		for filePath in args:
+			if not os.path.isfile(filePath):
+				print("Path not found "+filePath)
+				exit(0)
+
+		s3OtherFiles=[]
+		otherfilenames=[]
+
+		for filePath in args:
+			file_name=filePath.split("/")[-1]
+			print("Attempting {} upload".format(file_name))
+			s3Path=creds["cid"]+"/"+name+"/"+file_name
+			uploadmodel_resp=upload_to_showcase(s3Path,filePath,creds['cid'],auth_token)
+
+			s3OtherFiles.append(s3Path)
+			otherfilenames.append(file_name)
+			# if uploadmodel_resp=="Success":
+			print(file_name, uploadmodel_resp)
+
+		update_serving_model(servingmodel['id'],{"s3_other_files":s3OtherFiles,"otherfilenames":otherfilenames},auth_token)
+		
+	def removefiles(self,name,*args):
+
+		if not name or name=="":
+			print("Choose a specific project!")
+			return
+
+		if len(args)==0:
+			print("no files given")
+			return
+
+		creds=self.loggedin()		
+		auth_token=creds['token']
+
+		headers={"Content-Type":"application/json","Authorization": "Bearer "+auth_token}
+
+		name=find_full_project_name(name)
+
+		print("Fetching project "+name)
+
+		servingprojectsurl=BASE_URL+'/api/servingproject?where={"name":"%s","company":"%s"}' % (name,creds['cid'])
+		serving_project=requests.get(servingprojectsurl,headers=headers)
+
+		serving_project = parse_json(serving_project.text)
+
+		if len(serving_project)==0 or type(serving_project)==str:
+			print("Project not found")
+			return
+
+		servingproject=serving_project[0]
+
+		servingmodelsurl=BASE_URL+'/api/servingmodel?where={"servingproject":"%s"}' % (servingproject["id"])
+		servingmodel=requests.get(servingmodelsurl,headers=headers)
+		
+		servingmodel=parse_json(servingmodel.text)
+
+		if len(servingmodel)==0:
+			print("Some error occurred")
+			return
+
+		servingmodel = servingmodel[0]
+
+		if "otherfilenames" in servingmodel and len(servingmodel['otherfilenames'])>0:
+			for filePath in args:
+				file_name=filePath.split("/")[-1]
+				if file_name in servingmodel['otherfilenames']:
+					servingmodel['otherfilenames'].remove(file_name)
+
+				for s3Path in servingmodel['s3_other_files']:
+					if file_name in s3Path:
+						servingmodel['s3_other_files'].remove(s3Path)
+
+
+		update_serving_model(servingmodel['id'],{"otherfilenames":servingmodel['otherfilenames'],"s3_other_files":servingmodel['s3_other_files']},auth_token)
 
 
 	def ldeploy(self,file_path,model_type=None,notebook_type=None,requirements=None,predict=None,preprocess=None,postprocess=None,infra="standard",schema=None):
@@ -1858,8 +2226,6 @@ class Clouderizer(object):
 			pass
 		check_aws_cli_exists()
 
-		check_sam_cli_exists()
-
 		if not aws_region_set(LOCAL_DIR):
 			print("aws default region not set : aws configure set default.region {AWS_REGION}")
 			return
@@ -1874,6 +2240,8 @@ class Clouderizer(object):
 		creds=self.loggedin()
 		auth_token=creds["token"]
 
+		# userS3Bucket = get_user_s3_bucket(creds['cid'],creds['token'])
+
 		execution_type="notebook"
 		subtype="pythonscore"
 
@@ -1974,8 +2342,10 @@ class Clouderizer(object):
 						print("Project created!")
 
 						projectConfig = fetchprojectconfig(servingproject["id"])
+						projectConfig['lambda']="true"
 
-						notebookAccessUrl = lambda_deploy(LOCAL_DIR,"nb", projectName, projectName+"-stack", projectConfig, notebook_path,infra,pipPackages,timeout=15*60)
+						notebookAccessUrl = lambda_deploy_codebuild(LOCAL_DIR,"nb", projectName, projectName+"-stack", projectConfig, notebook_path,infra,pipPackages,timeout=15*60)
+						print("NOTEBOOK ACCESS URL : ",notebookAccessUrl)					
 						update_serving_model(servingmodel['id'],{"status":"Running","status_message":"Deployed successfully","accessUrl":notebookAccessUrl},auth_token)
 					else:
 						print("Notebook upload failed, could not deploy project")
@@ -2134,8 +2504,10 @@ class Clouderizer(object):
 						return
 
 					projectConfig = fetchprojectconfig(servingproject["id"])
+					projectConfig['lambda']="true"
 
-					modelAccessUrl = lambda_deploy(LOCAL_DIR,"model", projectName, projectName+"-stack", projectConfig, model_path,infra,pipPackages,preprocess_path,postprocess_path,predict_path)
+					modelAccessUrl = lambda_deploy_codebuild(LOCAL_DIR,"model", projectName, projectName+"-stack", projectConfig, model_path,infra,pipPackages,preprocess_path,postprocess_path,predict_path)
+					print("\nWEB APP URL : ",modelAccessUrl)
 					update_serving_model(servingmodel['id'],{"status":"Running","status_message":"Deployed successfully","accessUrl":modelAccessUrl},auth_token)
 				else:
 					print("Model upload failed, could not deploy project")
@@ -2144,13 +2516,40 @@ class Clouderizer(object):
 	def ldelete(self,name):
 		print("Deleting project in AWS Lambda")
 
+		creds = self.loggedin()
+		auth_token=creds['token']
+		headers={"Content-Type":"application/json","Authorization": "Bearer "+auth_token}
+		
 		name = find_full_project_name(name)
 
 		print("PROJECT:",name)
 
 		lambda_delete(name,LOCAL_DIR)	
 
-		self.delete(name)	
+		servingprojectsurl=BASE_URL+'/api/servingproject?where={"name":"%s","company":"%s"}' % (name,creds['cid'])
+		servingproject=requests.get(servingprojectsurl,headers=headers)
+		
+		servingproject=parse_json(servingproject.text)
+
+		if len(servingproject)==0:
+			print("Could not find project")
+			return
+
+		servingproject=servingproject[0]
+
+		servingmodelsurl=BASE_URL+'/api/servingmodel?where={"servingproject":"%s"}' % (servingproject["id"])
+		servingmodel=requests.get(servingmodelsurl,headers=headers)
+		
+		servingmodel=parse_json(servingmodel.text)
+
+		if len(servingmodel)==0:
+			print("Some error occurred")
+			return
+
+		servingmodel = servingmodel[0]
+
+		update_serving_model(servingmodel['id'],{"status":"Not Running","status_message":"","accessUrl":"","lambda":"false"},auth_token)
+		# self.delete(name)	
 
 def main():
 	if len(sys.argv)==1:
