@@ -18,6 +18,7 @@ import shutil
 import uuid
 import logging
 from pathlib import Path
+from clouderizer import globals
 
 # import boto3
 
@@ -73,6 +74,11 @@ except ModuleNotFoundError:
 
 logger = logging.getLogger(__name__)
 
+# def create_aws_codebuild_buildspec_template_files(
+
+# ):
+
+
 def create_aws_lambda_cloudformation_template_file(
     project_name,
     project_dir,
@@ -104,7 +110,7 @@ def create_aws_lambda_cloudformation_template_file(
             'Type': 'AWS::Serverless::Function',
             'Properties': {
                 'PackageType' : "Image",
-                'FunctionName': f'{namespace}-{deployment_name}-{api_name}',
+                'FunctionName': f'{namespace}-{deployment_name}',
                 'Timeout': timeout,
                 'MemorySize': memory_size,
                 'Events': {
@@ -128,7 +134,7 @@ def create_aws_lambda_cloudformation_template_file(
             },
             'Metadata': {
                 'Dockertag' : "latest",
-                'DockerContext' : project_dir,
+                'DockerContext' : '.',
                 'Dockerfile' : "Dockerfile"
             }
         }
@@ -149,6 +155,58 @@ amazonaws.com/function/#PROJECT_NAME#"
     return template_file_path
 
 
+def create_aws_codebuild_cloudformation_template_file(
+    project_name,
+    project_dir,
+    s3_dir_path
+):
+
+    # template_path = os.getcwd() + '/clouderizer_beta/templates/codebuild_cloudformation_template.yaml'
+
+    template_path = globals.TEMPLATES_LOC + 'codebuild_cloudformation_template.yaml'
+    f = open(template_path,'r')
+    data = f.read()
+    f.close()
+
+    data=data.replace("#PROJECT_NAME#","cldz-codebuild")
+    data=data.replace("#S3_PATH#",s3_dir_path)
+
+    f = open(project_dir+'/codebuild.yaml','w+')
+    f.write(data)
+    f.close()
+
+def create_aws_codebuild_buildspec(stackName,awsRegion,modelName,imageRepo,project_dir,funcs):
+    predict=funcs[0]
+    preprocess=funcs[1]
+    postprocess=funcs[2]
+
+    # template_path = os.getcwd() + '/clouderizer_beta/templates/codebuild_buildspec.yaml'
+    template_path = globals.TEMPLATES_LOC + 'codebuild_buildspec.yaml'
+    f = open(template_path,'r')
+    data = f.read()
+    f.close()
+
+    data = data.replace("#STACK_NAME#",stackName)
+    data = data.replace("#AWS_REGION#",awsRegion)
+    data = data.replace("#MODEL_NAME#",modelName)
+    data = data.replace("#IMAGE_REPO#",imageRepo)
+
+    if predict:
+        data = data.replace("#PREDICT_FUNCTION#","cp pypredict.py lambda-dir/function/")
+
+    if preprocess:
+        data = data.replace("#PREPROCESS_FUNCTION#","cp preprocess.py lambda-dir/function/")
+    
+    if postprocess:
+        data = data.replace("#POSTPROCESS_FUNCTION#","cp postprocess.py lambda-dir/function/")
+    
+    data = data.replace("#PREDICT_FUNCTION#","echo No predict function")
+    data = data.replace("#PREPROCESS_FUNCTION#","echo No preprocess function")
+    data = data.replace("#POSTPROCESS_FUNCTION#","echo No postprocess function")
+
+    f = open(project_dir+'/buildspec.yaml','w+')
+    f.write(data)
+    f.close()
 
 def _create_aws_lambda_cloudformation_template_file(
     project_dir,
